@@ -1,4 +1,4 @@
-package Manta::Client 0.4;
+package Manta::Client 0.5;
 
 use strict;
 use warnings;
@@ -8,7 +8,6 @@ use JSON::Parse 'parse_json';
 use LWP::UserAgent;
 use MIME::Base64 'encode_base64';
 use Net::SSH::Perl::Key;
-use Data::Dumper;
 
 sub new {
 	my $class = shift;
@@ -52,7 +51,6 @@ sub _request {
 			return undef;
 		}
 	} elsif ($params{method} eq "PUT") {
-print Dumper($ua);
 		$response = $ua->put("$self->{url}/$params{path}", Content => $params{content}, %$h);
 		return !!$response->is_success;
 	} elsif ($params{method} eq "DELETE") {
